<?php 
  include ("slooze_local.php");
?>
<!doctype html public "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
<head>
<title>Album Photo</title>
<link rel="stylesheet" type="text/css" href="style.css">
</head>

<body>

<?php
$mySlooze = new MySlooze(0);
$myRender = new BasicRender($mySlooze);
$mySlooze->setRender($myRender);
$vars = $mySlooze->validateInputs();
$vars['action'] = 'remindPassword';
$mySlooze->handleAction(&$vars);
$myRender->showMessages();
?>

<p>coucou gros ours.</p>

</body>
</html>
<?php page_close() ?>
